#
# spec file for package python-encore
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
Name:           python-encore
Version:        0.8.0
Release:        2.4
Summary:        Low-level core modules for building Python applications
License:        Apache-2.0 AND LGPL-2.1-only AND Python-2.0
Group:          Development/Languages/Python
URL:            https://github.com/enthought/encore
Source:         https://files.pythonhosted.org/packages/source/e/encore/encore-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-requests
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
# /SECTION
%python_subpackages

%description
This package consists of a collection of core utility packages useful
for building Python applications.  This package is intended to be at
the bottom of the software stack and have zero required external
dependencies aside from the Python Standard Library.

Packages:

  * Events: A package implementing a lightweight application-wide
    Event dispatch system.  Listeners can subscribe to events based
    on Event type or by filtering on event attributes.  Typical uses
    include UI components listening to low-level progress
    notifications and change notification for distributed resources.

  * Storage: Abstract base classes and concrete implementations of a
    basic key-value storage API. The API is intended to be general
    purpose enough to support a variety of local and remote storage
    systems.

  * Concurrent: A package of tools for handling concurrency within
    applications.

  * Terminal: Some utilities for working with text-based terminal
    displays.

%prep
%setup -q -n encore-%{version}
# port tests to python312
sed -i 's/assertEquals/assertEqual/' encore/storage/tests/*.py
sed -i 's/\\\*/*/g' encore/concurrent/futures/enhanced_thread_pool_executor.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/enthought/encore/issues/112
sed -i 's:import mock:from unittest import mock:' encore/events/tests/test_event_manager.py
%pytest

%files %{python_files}
%doc CHANGES.txt README.rst
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Wed Feb 21 2024 Markéta Machová <mmachova@suse.com>
- Fix tests with python312
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * This release brings build and distribution machinery up to date, adds
    support for more recent Python 3 versions, and drops support for Python 2.
    We no longer support Python versions older than 3.6.
  * Removed Python 2 compatibility code.
  * Migrated CI from Travis CI and Appveyor to GitHub Actions.
  * Updated copyright headers.
  * Modernised build machinery.
  * Updated documentation to use the Enthought Sphinx Theme.
* Mon May  2 2022 pgajdos@suse.com
- do not require python-mock for build
* Tue May 18 2021 pgajdos@suse.com
- use %%pytest macro
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Wed May 16 2018 toddrme2178@gmail.com
- Update to 0.7.0
  * Python 3 support (PR#102).
  * Add a delayed asynchronizer that enforces an interval between operations (PR#63).
- Implement single-spec version
* Sun May 24 2015 toddrme2178@gmail.com
- Update to 0.6.0
  + New Features
  * Added `MountedStore` store subclass. (PR#75)
  * Added `concurrent.threadtools` module and `synchronized`
    decorator. (PR #91)
  * Added the ability to request ranges of data from store
    values. (PR#76)
  + Improvements
  * Improved `get_data()` calls for `DynamicURLStore`
    instances. (PR#90)
  * `DynamicURLStore` now accepts `401` return codes to
    indicate unauthorised keys. (PR#88)
  * `DynamicURLStore` now implements `delete()` via sending an
    HTTP DELETE to the appropriate URL. (PR#87)
  * `DynamicURLStore` uses streaming to send data. (PR#82)
  * Refuse server-side compression for the `DynamicURLStore`.
    (PR#82)
  + Fixes
  * Fix attribute collision with futures 2.2.0. (PR#94)
  * Fix race condition in file store. (PR#83)
  * Various other minor fixes.
* Mon Oct 13 2014 toddrme2178@gmail.com
- Update to 0.5.1
  * no changelog
- Update source to pypi url.
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 0.3
  * no changelog
* Tue May 22 2012 toddrme2178@gmail.com
- Initial spec file
